@@ -67,8 +67,8 @@ public class ModelloTask extends Task {
 
         addToClassPath("/usr/share/java/plexus-build-api.jar");
         addToClassPath("/usr/share/java/plexus-utils2.jar");
-        addToClassPath("/usr/share/java/plexus-classworlds2.jar");
-        addToClassPath("/usr/share/java/plexus-container-default-1.5.jar");
+        addToClassPath("/usr/share/java/plexus-classworlds.jar");
+        addToClassPath("/usr/share/java/plexus-container-default.jar");
         addToClassPath("/usr/share/java/modello-core.jar");
         addToClassPath("/usr/share/java/modello-plugin-converters.jar");
         addToClassPath("/usr/share/java/modello-plugin-dom4j.jar");
